@@ -25,11 +25,16 @@
 #endif
 
 #include <glib/gi18n.h>
+#include <gdk/gdk.h>
 
 G_BEGIN_DECLS
 
 #define MT_ICON_NAME  "input-mouse"
 
+#define MOUSETWEAKS_DBUS_NAME  "org.gnome.Mousetweaks"
+#define MOUSETWEAKS_DBUS_IFACE "org.gnome.Mousetweaks"
+#define MOUSETWEAKS_DBUS_PATH  "/org/gnome/Mousetweaks"
+
 #define MT_GCONF_HOME "/desktop/gnome/accessibility/mouse"
 #define OPT_THRESHOLD MT_GCONF_HOME "/threshold"
 #define OPT_SSC       MT_GCONF_HOME "/delay_enable"
@@ -48,20 +53,23 @@ G_BEGIN_DECLS
 #define GNOME_MOUSE_DIR "/desktop/gnome/peripherals/mouse"
 #define GNOME_MOUSE_ORIENT GNOME_MOUSE_DIR "/left_handed"
 
-enum {
+enum
+{
     DWELL_MODE_CTW = 0,
     DWELL_MODE_GESTURE
 };
 
-enum {
+typedef enum
+{
     DWELL_CLICK_TYPE_RIGHT = 0,
     DWELL_CLICK_TYPE_DRAG,
     DWELL_CLICK_TYPE_DOUBLE,
     DWELL_CLICK_TYPE_SINGLE,
     N_CLICK_TYPES
-};
+} MtClickType;
 
-enum {
+enum
+{
     DIRECTION_LEFT = 0,
     DIRECTION_RIGHT,
     DIRECTION_UP,
@@ -69,18 +77,19 @@ enum {
     DIRECTION_DISABLE
 };
 
-typedef enum {
+typedef enum
+{
     MT_MESSAGE_ERROR = 0,
     MT_MESSAGE_WARNING,
     MT_MESSAGE_QUESTION,
     MT_MESSAGE_LOGOUT
 } MtMessageType;
 
-void mt_common_show_help   (GdkScreen     *screen,
-			    guint32        timestamp);
-gint mt_common_show_dialog (const gchar   *primary,
-			    const gchar   *secondary,
-			    MtMessageType  type);
+void         mt_common_show_help         (GdkScreen     *screen,
+                                          guint32        timestamp);
+gint         mt_common_show_dialog       (const gchar   *primary,
+                                          const gchar   *secondary,
+                                          MtMessageType  type);
 
 G_END_DECLS
 
